pub struct Events { /* private fields */ }Expand description
A small event handler that wrap crossterm input and tick event. Each event
type is handled in its own thread and returned to a common Receiver
Implementations