pub struct Events { /* private fields */ }
A small event handler that wrap crossterm input and tick event. Each event type is handled in its own thread and returned to a common Receiver

Implementations

Constructs an new instance of Events with the default config.

Attempts to read an event.