pub struct Reflector<K> where
K: Resource + 'static,
K::DynamicType: Hash + Eq, {
pub reader: Store<K>,
pub stream: Pin<Box<dyn Stream<Item = Result<Event<K>>> + Send>>,
}Fields
reader: Store<K>stream: Pin<Box<dyn Stream<Item = Result<Event<K>>> + Send>>Implementations
Methods from Deref<Target = Store<K>>
pub fn get(&self, key: &ObjectRef<K>) -> Option<Arc<K>>
pub fn get(&self, key: &ObjectRef<K>) -> Option<Arc<K>>
Retrieve a clone() of the entry referred to by key, if it is in the cache.
key.namespace is ignored for cluster-scoped resources.
Note that this is a cache and may be stale. Deleted objects may still exist in the cache
despite having been deleted in the cluster, and new objects may not yet exist in the cache.
If any of these are a problem for you then you should abort your reconciler and retry later.
If you use kube_rt::controller then you can do this by returning an error and specifying a
reasonable error_policy.